@@ -9,7 +9,7 @@ use Catmandu::Store::Solr::CQL;
 use Catmandu::Error;
 use Moo;
 
-our $VERSION = "0.0214";
+our $VERSION = "0.0215";
 
 with 'Catmandu::Bag';
 with 'Catmandu::Searchable';
@@ -147,7 +147,7 @@ sub commit {
         eval { $solr->commit } or push @{ $err ||= [] }, $@;
     }
 
-    if(defined $err && $self->store->on_error == 'throw'){
+    if(defined $err && $self->store->on_error eq 'throw'){
         Catmandu::Error->throw($err->[0]);
     }
 }
