@@ -3,7 +3,7 @@ package Catmandu::Store::Solr::Searcher;
 use Catmandu::Sane;
 use Moo;
 
-our $VERSION = "0.0214";
+our $VERSION = "0.0215";
 
 with 'Catmandu::Iterable';
 
@@ -13,6 +13,11 @@ has start => (is => 'ro', required => 1);
 has limit => (is => 'ro', required => 1);
 has sort  => (is => 'ro', required => 0);
 has total => (is => 'ro');
+has fl => (
+    is => 'ro',
+    lazy => 1,
+    default => sub { "*" }
+);
 
 sub generator {
     my ($self) = @_;
@@ -38,6 +43,7 @@ sub generator {
                 rows => $limit,
                 fq => $fq,
                 sort => $self->sort,
+                fl => $self->fl,
                 facet => "false",
                 spellcheck => "false"
             })->content->{response}{docs};
